# MobioUtilities

Project tập trung các thư viện cơ bản dùng trong các Project Python của Mobio.

Danh sách các thư viện:
* m-singleton==0.3' (https://pypi.org/project/m-singleton)
* 'm-monitor==0.6'  (https://pypi.org/project/m-monitor)
* 'm-validator==0.1' (https://pypi.org/project/m-validator)
* 'm-filetypes==0.1.5' (https://pypi.org/project/m-filetypes)
* 'm-cipher==1.5.1' (https://pypi.org/project/m-cipher)
* 'm-schedule==0.6.7' (https://pypi.org/project/m-schedule)
* 'm-caching==0.1.8' (https://pypi.org/project/m-caching)
* 'm-threadpool==0.2' (https://pypi.org/project/m-threadpool)
* 'm-formatter-logging>=1.0.2' (https://pypi.org/project/m-formatter-logging)
* 'm-kafka-sdk-v2==0.1.5' (https://pypi.org/project/m-kafka-sdk-v2)